@@ -1,7 +1,7 @@
 package Twitter::API;
 # ABSTRACT: A Twitter REST API library for Perl
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0108';
 use 5.14.1;
 use Moo;
 use Carp;
@@ -18,7 +18,7 @@ use URL::Encode ();
 use WWW::OAuth;
 use namespace::clean;
 
-with qw/MooX::Traits Twitter::API::Migration/;
+with qw/MooX::Traits/;
 sub _trait_namespace { 'Twitter::API::Trait' }
 
 has [ qw/consumer_key consumer_secret/ ] => (
@@ -104,6 +104,15 @@ has json_parser => (
     },
 );
 
+around BUILDARGS => sub {
+    my ( $next, $class ) = splice @_, 0, 2;
+
+    my $args = $class->$next(@_);
+    croak 'use new_with_traits' if exists $args->{traits};
+
+    return $args;
+};
+
 sub get  { shift->request( get => @_ ) }
 sub post { shift->request( post => @_ ) }
 
@@ -422,12 +431,12 @@ __END__
 
 Twitter::API - A Twitter REST API library for Perl
 
-=for html <a href="http://github.com/badges/stability-badges"><img src="http://badges.github.io/stability-badges/dist/experimental.svg" alt="experimental" /></a>
-<a href="http://travis-ci.org/semifor/Twitter-API"><img src="https://secure.travis-ci.org/semifor/Twitter-API.svg" alt="Build Status" /></a>
+=for html <img src="https://img.shields.io/badge/stability-experimental-orange.svg" alt="experimental" />
+<a href="https://travis-ci.org/semifor/Twitter-API"><img src="https://travis-ci.org/semifor/Twitter-API.svg?branch=master" alt="Build Status" /></a>
 
 =head1 VERSION
 
-version 0.0107
+version 0.0108
 
 =head1 SYNOPSIS
 
@@ -569,9 +578,9 @@ inflate API call results to objects via L<Twitter::API::Trait::InflateObjects>
 =head2 Migration from Net::Twitter and Net::Twitter::Lite
 
 Migration support is included to assist users migrating from L<Net::Twitter>
-and L<Net::Twitter::Lite>. It will be removed from a future release (or at
-least not included by default). See L<Twitter::API::Migration> for details
-about migrating your existing Net::Twitter/::Lite applications.
+and L<Net::Twitter::Lite>. It will be removed from a future release. See
+L<Migration|Twitter::API::Trait::Migration> for details about migrating your
+existing Net::Twitter/::Lite applications.
 
 =head2 Normal usage
 
