@@ -1,6 +1,6 @@
 package Twitter::API::Trait::AppAuth;
 # ABSTRACT: App-only (OAuth2) Authentication
-$Twitter::API::Trait::AppAuth::VERSION = '0.0107';
+$Twitter::API::Trait::AppAuth::VERSION = '0.0108';
 use Moo::Role;
 use Carp;
 use URL::Encode qw/url_encode url_decode/;
@@ -8,7 +8,7 @@ use namespace::clean;
 
 requires qw/
     _url_for access_token add_authorization api_url consumer_key
-    consumer_secret request request_access_token
+    consumer_secret request
 /;
 
 # private methods
@@ -103,7 +103,7 @@ Twitter::API::Trait::AppAuth - App-only (OAuth2) Authentication
 
 =head1 VERSION
 
-version 0.0107
+version 0.0108
 
 =head1 SYNOPSIS
 
